@@ -33,7 +33,7 @@ PATH=/bin:/usr/bin; export PATH
 
 GNATS_ROOT=xGNATS_ROOTx
 VERSION=xVERSIONx
-LIBDIR=xLIBDIRx
+LIBEXECDIR=xLIBEXECDIRx
 MAIL_AGENT="xMAIL_AGENTx"
 GNATS_USER="xGNATS_USERx"
 
@@ -58,7 +58,7 @@ if [ ! -f $3 ]; then exit 0; fi
 STATE=`grep '^>State:' $3 | sed -e 's,^>State:[ 	]*,,g'`
 SYNOPSIS=`grep '^>Synopsis:' $3 | sed -e 's,^>Synopsis:[ 	]*,,g'`
 RESPONSIBLE=`grep '^>Responsible:' $3 | sed -e 's,^>Responsible:[ 	]*,,g'`
-RESP_ADDR=`$LIBDIR/gnats/pr-addr "$RESPONSIBLE"`
+RESP_ADDR=`$LIBEXECDIR/gnats/pr-addr "$RESPONSIBLE"`
 
 # $DEBUG_MODE is set to 0 when debug is off in the config file
 if [ "x$DEBUG_MODE" = "x1" ]; then
