@@ -1,5 +1,5 @@
 /* Commands for the GNATS server.
-   Copyright (C) 1994, 1995 Free Software Foundation, Inc.
+   Copyright (C) 1994, 95, 95, 1997 Free Software Foundation, Inc.
    Contributed by Brendan Kehoe (brendan@cygnus.com).
 
 This file is part of GNU GNATS.
@@ -26,6 +26,7 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 char *current_pr = (char *)NULL;
 
 #ifdef HAVE_KERBEROS
+#include <des.h>
 #include <krb.h>
 #ifndef HAVE_KRB_GET_ERR_TEXT
 #define krb_get_err_text(status) krb_err_txt[status]
@@ -42,19 +43,6 @@ extern int client_authorized;
 
 static int chk_nargs			PARAMS((int, char*));
 
-/* Only say `PRs follow' once.  */
-static int started = 0;
-
-void
-start_data ()
-{
-  if (!started)
-    {
-      printf ("%d PRs follow.\r\n", CODE_PR_READY);
-      started = 1;
-    }
-}
-
 static int
 chk_nargs (ac, what)
      int ac;
@@ -310,7 +298,7 @@ do_query (ac, av)
   Index *j;
   int hit = 0;
 
-  started = 0;
+  reset_started ();
 
   if (ac == 0)
     {
@@ -466,7 +454,6 @@ GNATS_lock (ac, av)
   if (! path)
     return;
 
-  start_data ();
   query_format = FORMAT_FULL;
   daemon_pr (path, 1);
   printf (".\r\n");
@@ -524,6 +511,8 @@ GNATS_lkdb (ac, av)
 
   /* This does the error for us.  */
   lock_gnats ();
+
+  printf ("%d GNATS database is now locked.\r\n", CODE_OK);
 }
 
 void
@@ -537,7 +526,14 @@ GNATS_undb (ac, av)
       return;
     }
 
-  unlock_gnats ();
+  if (unlock_gnats () < 0)
+    {
+      printf ("%d failed unlocking GNATS database.\r\n",
+	      CODE_ERROR);
+      return;
+    }
+
+  printf ("%d GNATS database is now unlocked.\r\n", CODE_OK);
 }
 
 void
@@ -815,6 +811,38 @@ GNATS_catg (ac, av)
   printf ("%d Ok.\r\n", CODE_OK);
 }
 
+void
+GNATS_synp (ac, av)
+     int ac;
+     char **av;
+{
+  static char *buf = (char *)NULL;
+
+  if (! chk_nargs (ac, "synopsis"))
+    return;
+
+  if (buf)
+    xfree (buf);
+  synopsis = buf = strdup(*av);
+  printf ("%d Ok.\r\n", CODE_OK);
+}
+
+void
+GNATS_rlse (ac, av)
+     int ac;
+     char **av;
+{
+  static char *buf = (char *)NULL;
+
+  if (! chk_nargs (ac, "release"))
+    return;
+
+  if (buf)
+    xfree (buf);
+  release = buf = strdup(*av);
+  printf ("%d Ok.\r\n", CODE_OK);
+}
+
 void
 GNATS_conf (ac, av)
      int ac;
@@ -922,20 +950,6 @@ GNATS_kywd (ac, av)
 
   printf ("%d Ok.\r\n", CODE_OK);
 }
-#endif
-
-void
-GNATS_prio (ac, av)
-     int ac;
-     char **av;
-{
-  if (! chk_nargs (ac, "priority"))
-    return;
-
-  searching = 1;
-  search->priority = (char *) strdup (av[0]);
-  printf ("%d Ok.\r\n", CODE_OK);
-}
 
 void
 GNATS_bfor (ac, av)
@@ -952,7 +966,7 @@ GNATS_bfor (ac, av)
     printf ("%d Cannot parse the date: %s.\r\n", CODE_INVALID_DATE, *av);
   else
     {
-      before = t;
+      required_before = t;
       searching = 1;
       printf ("%d Ok.\r\n", CODE_OK);
     }
@@ -973,11 +987,65 @@ GNATS_aftr (ac, av)
     printf ("%d Cannot parse the date: %s.\r\n", CODE_INVALID_DATE, *av);
   else
     {
-      after = t;
+      required_after = t;
       searching = 1;
       printf ("%d Ok.\r\n", CODE_OK);
     }
 }
+#endif
+
+void
+GNATS_prio (ac, av)
+     int ac;
+     char **av;
+{
+  if (! chk_nargs (ac, "priority"))
+    return;
+
+  searching = 1;
+  search->priority = (char *) strdup (av[0]);
+  printf ("%d Ok.\r\n", CODE_OK);
+}
+
+void
+GNATS_abfr (ac, av)
+     int ac;
+     char **av;
+{
+  time_t t;
+
+  if (! chk_nargs(ac, "date"))
+    return;
+
+  t = get_date (*av, NULL);
+  if (t == -1)
+    printf ("%d Cannot parse the date: %s.\r\n", CODE_INVALID_DATE, *av);
+  else
+    {
+      arrived_before = t;
+      printf ("%d Ok.\r\n", CODE_OK);
+    }
+}
+
+void
+GNATS_araf (ac, av)
+     int ac;
+     char **av;
+{
+  time_t t;
+
+  if (! chk_nargs(ac, "date"))
+    return;
+
+  t = get_date (*av, NULL);
+  if (t == -1)
+    printf ("%d Cannot parse the date: %s.\r\n", CODE_INVALID_DATE, *av);
+  else
+    {
+      arrived_after = t;
+      printf ("%d Ok.\r\n", CODE_OK);
+    }
+}
 
 void
 GNATS_vdat (ac, av)
@@ -1082,13 +1150,13 @@ GNATS_rset (ac, av)
   originator = (char *) NULL;
   xfree (class);
   class = (char *) NULL;
-  before = after = (time_t)0;
   searching = skip_closed = 0;
   xfree (text_search);
   text_search = (char *) NULL;
   xfree (m_text_search);
   m_text_search = (char *) NULL;
 #ifdef GNATS_RELEASE_BASED
+  required_before = required_after = (time_t)0;
   xfree (quarter);
   quarter = (char *) NULL;
   xfree (keywords);
@@ -1316,7 +1384,6 @@ GNATS_auth (ac, av)
       p = k.buf + len + 1;
       tohex (k.buf, p, len);
       printf ("x%s\r\n", p);
-      fflush (stdout);
 
       /* Okay, authentication step is done.  Now check authorization.  */
       if (kuserok (&k.auth, desired_user))
@@ -1420,12 +1487,16 @@ GNATS_help (ac, av)
 	  CODE_INFORMATION);
   printf ("%d-   CATG <category>         search for PRs in <category>\r\n",
 	  CODE_INFORMATION);
+  printf ("%d-   SYNP <synopsis>         search for PRs have the synopsis <synopsis>\r\n",
+	  CODE_INFORMATION);
   printf ("%d-   RESP <person>           search for PRs that <person> is responsible for\r\n",
 	  CODE_INFORMATION);
   printf ("%d-   SUBM <submitter>        search for PRs with a submitter <submitter>\r\n",
 	  CODE_INFORMATION);
   printf ("%d-   ORIG <originator>       search for PRs with an originator <originator>\r\n",
 	  CODE_INFORMATION);
+  printf ("%d-   RLSE <release>          search for PRs from the release <release>\r\n",
+	  CODE_INFORMATION);
   printf ("%d-   CLSS <class>            search for PRs of class <class>\r\n",
 	  CODE_INFORMATION);
 #ifdef GNATS_RELEASE_BASED
@@ -1433,7 +1504,19 @@ GNATS_help (ac, av)
 	  CODE_INFORMATION);
   printf ("%d-   KYWD <keywords>         search for PRs with Keywords <keywords>\r\n",
 	  CODE_INFORMATION);
+  printf ("%d-   BFOR <date>             find PRs with Date-Required: before <date>\r\n",
+	  CODE_INFORMATION);
+  printf ("%d-   AFTR <date>             find PRs with Date-Required: after <date>\r\n",
+	  CODE_INFORMATION);
 #endif
+  printf ("%d-   PRIO <priority>         search for PRs which are of the priority <priority>\r\n",
+	  CODE_INFORMATION);
+  printf ("%d-   ABFR <date>             find all PRs that arrived before <date>\r\n",
+	  CODE_INFORMATION);
+  printf ("%d-   ARAF <date>             find all PRs that arrived before <date>\r\n",
+	  CODE_INFORMATION);
+  printf ("%d-   VDATE <date>            validate the format of <date>\r\n",
+	  CODE_INFORMATION);
   printf ("%d-   SVTY <sevty>            search for PRs which are of the severity <sevty>\r\n",
 	  CODE_INFORMATION);
   printf ("%d-   STAT <state>            search for PRs in the state <state>\r\n",
