@@ -30,12 +30,6 @@ static void create_report	PARAMS((char *, int));
 static int get_bug_number	PARAMS((void));
 static void notify_responsible	PARAMS((char*, char*, char*, char*, char*, int, struct tm *));
 
-void
-start_data ()
-{
-  return; /* Nothing */
-}
-
 static struct bad_enum *bad_enums = NULL;
 
 void
@@ -403,7 +397,7 @@ check_if_reply ()
   regex.translate = case_fold;
 
   /* too restrictive? */
-#define PAT "(.*re[ \t]*(\[[0-9]+\])?:)?[ \t]*([-a-z0-9_+.]*/([0-9]+))"
+#define PAT "(.*re[ \t]*(\\[[0-9]+\\])?:)?[ \t]*([-a-z0-9_+.]*/([0-9]+))"
   re_compile_pattern (PAT, strlen (PAT), &regex);
   i = re_match (&regex, s, strlen (s), 0, &regs);
 
@@ -752,7 +746,7 @@ append_report (infile, filename)
   *b = '\0';
 
   /* Separate this from the rest of the audit trail.  */
-  APPEND_STRING ("\n", buf, b, buf_len, buf_max, l, 0);
+  APPEND_STRING ((char*)"\n", buf, b, buf_len, buf_max, l, 0);
   sprintf (line, "From: %s", from);
   APPEND_STRING (line, buf, b, buf_len, buf_max, l, 0);
   sprintf (line, "To: %s", to);
@@ -763,12 +757,12 @@ append_report (infile, filename)
   APPEND_STRING (line, buf, b, buf_len, buf_max, l, 0);
   sprintf (line, "Date: %s", date);
   APPEND_STRING (line, buf, b, buf_len, buf_max, l, 0);
-  APPEND_STRING ("\n", buf, b, buf_len, buf_max, l, 0);
+  APPEND_STRING ((char*)"\n", buf, b, buf_len, buf_max, l, 0);
 
   while ((fgets (line, STR_MAX, infile)) != NULL)
     {
       /* Quote all correspondence so PR doesn't get messed up */
-      APPEND_STRING (" ", buf, b, buf_len, buf_max, l, 0);
+      APPEND_STRING ((char*)" ", buf, b, buf_len, buf_max, l, 0);
       APPEND_STRING (line, buf, b, buf_len, buf_max, l, 0);
     }
   buf[buf_len] = '\0';
