@@ -1,6 +1,6 @@
 /* Typedefs and defines for the files GNATS will read and write.
-   Copyright (C) 1993 Free Software Foundation, Inc.
-   Contributed by Tim Wicinski (wicinski@barn.com).
+   Copyright (C) 1993-96, 1997 Free Software Foundation, Inc.
+   Originally contributed by Tim Wicinski (wicinski@barn.com).
 
 This file is part of GNU GNATS.
 
@@ -81,6 +81,16 @@ typedef struct responsible_entry {
      the address, assuming that it is a local user.  */
   char *alias;
 
+  /* Whether this entry is "authentic" or not.  I.e., if this is true,
+     then the entry indicates someone who was found either in the
+     "responsible" field or in the passwd file; if it's false, then
+     the entry indicates an entry that was constructed dynamically
+     (e.g., perhaps because the person left the company and is no
+     longer in the passwd file, but they still appear in the
+     Responsible field of some PRs so the value should be considered
+     valid). */
+  int authentic;
+
   /* pointer to next record */
   struct responsible_entry *next;
 
