@@ -240,7 +240,7 @@ extern void unblock_signals             PARAMS((void));
 extern void add_to_index                PARAMS((void));
 extern int is_gnats_locked               PARAMS((void));
 extern int lock_gnats                    PARAMS((void));
-extern void unlock_gnats                 PARAMS((void));
+extern int unlock_gnats                  PARAMS((void));
 extern void punt                        PARAMS((int, ...));
 extern int copy_file                    PARAMS((char *, char *));
 extern void add_to_index		PARAMS((void));
