@@ -79,8 +79,16 @@ fi
 
 for f in $FILES; do
   if [ ! -f ${DATADIR}/gnats/dist/$f ]; then
-    echo "$0: $f does not exist."
-    exit 1
+    if [ ! -f ${DATADIR}/gnats/dist/$f.gz ]; then
+      echo "$0: $f does not exist."
+      exit 1
+    else
+      rm -f $1/$f
+      gzip -dc ${DATADIR}/gnats/dist/$f >$1/$f
+    fi
+  else
+    rm -f $1/$f
+    cp ${DATADIR}/gnats/dist/$f $1
   fi
   rm -f $1/$f
   cp ${DATADIR}/gnats/dist/$f $1
