@@ -1,5 +1,5 @@
 /* Perform queries on the contents of a GNATS database.
-   Copyright (C) 1993, 1994, 1995 Free Software Foundation, Inc.
+   Copyright (C) 1993, 94, 95, 96, 1997 Free Software Foundation, Inc.
    Contributed by Brendan Kehoe (brendan@cygnus.com).
 
 This file is part of GNU GNATS.
@@ -31,17 +31,18 @@ int restricted = 0;
 /* If 1, we're running the daemon.  */
 int is_daemon = 0;
 
-extern FILE *outfile;
-
 struct option long_options[] =
 {
   {"category", 1, NULL, 'c'},
+  {"synopsis", 1, NULL, 'y'},
   {"confidential", 1, NULL, 'C'},
+  {"debug", 0, NULL, 'D'},
   {"directory", 1, NULL, 'd'},
   {"full", 0, NULL, 'F'},
   {"help", 0, NULL, 'h'},
   {"multitext", 1, NULL, 'm'},
   {"originator", 1, NULL, 'O'},
+  {"release", 1, NULL, 'A'},
   {"class", 1, NULL, 'L'},
 #ifdef GNATS_RELEASE_BASED
   {"quarter", 1, NULL, 'Q'},
@@ -74,12 +75,6 @@ struct option long_options[] =
 
 void usage (), version ();
 
-void
-start_data ()
-{
-  return; /* Nothing */
-}
-
 int
 query_pr (p, s)
      char *p;
@@ -166,11 +161,40 @@ main (argc, argv)
   s = (Index *) xmalloc (sizeof (Index));
   memset (s, 0, sizeof (Index));
 
-  while ((optc = getopt_long (argc, argv, "c:C:d:e:L:m:o:O:p:Ps:S:r:t:u:U:VFixhqRjkl",
+#ifdef GNATS_RELEASE_BASED
+  while ((optc = getopt_long (argc, argv, "A:a:c:C:D:d:e:K:L:m:o:O:p:PQ:s:S:r:t:u:U:y:VFixhqRjkl",
+#else
+  while ((optc = getopt_long (argc, argv, "A:b:c:C:D:d:e:L:m:o:O:p:Ps:S:r:t:u:U:y:VFixhqRjkl",
+#endif
 			      long_options, (int *) 0)) != EOF)
     {
       switch (optc)
 	{
+	case 'A':
+	  release = optarg;
+	  searching = 1;
+	  break;
+
+	case 'a':
+	  arrived_after = get_date (optarg, NULL);
+	  if (arrived_after < 0)
+	    {
+	      fprintf (stderr, "%s: could not decypher `%s'\n",
+		       program_name, optarg);
+	      exit (1);
+	    }
+	  break;
+
+	case 'b':
+	  arrived_before = get_date (optarg, NULL);
+	  if (arrived_after < 0)
+	    {
+	      fprintf (stderr, "%s: could not decypher `%s'\n",
+		       program_name, optarg);
+	      exit (1);
+	    }
+	  break;
+
 	case 'd':
 	  spec_gnats_root = optarg;
 	  break;
@@ -209,6 +233,10 @@ main (argc, argv)
 	  searching = 1;
 	  break;
 
+	case 'D':
+	  /* debug case, unused in the non-networked query-pr */
+	  break;
+
 	case 'e':
 	  s->severity = optarg;
 	  searching = 1;
@@ -298,9 +326,10 @@ main (argc, argv)
 	  lists++;
 	  break;
 
+#ifdef GNATS_RELEASE_BASED
 	case 'u':
-	  before = get_date (optarg, NULL);
-	  if (before < 0)
+	  required_before = get_date (optarg, NULL);
+	  if (required_before < 0)
 	    {
 	      fprintf (stderr, "%s: could not decypher `%s'\n",
 		       program_name, optarg);
@@ -310,8 +339,8 @@ main (argc, argv)
 	  break;
 
 	case 'U':
-	  after = get_date (optarg, NULL);
-	  if (after < 0)
+	  required_after = get_date (optarg, NULL);
+	  if (required_after < 0)
 	    {
 	      fprintf (stderr, "%s: could not decypher `%s'\n",
 		       program_name, optarg);
@@ -319,6 +348,12 @@ main (argc, argv)
 	    }
 	  searching = 1;
 	  break;
+#endif
+
+	case 'y':
+	  synopsis = optarg;
+	  searching = 1;
+	  break;
 
 	case 'h':
 	  usage (0);
@@ -393,32 +428,35 @@ usage (s)
 {
 #ifdef GNATS_RELEASE_BASED
   fprintf (stderr, "\
-Usage: %s [-FhiPqVx] [-C confidential] [-c category] [-d directory]\n\
+Usage: %s [-FhiPRqVx] [-C confidential] [-c category] [-d directory]\n\
        [-e severity] [-m mtext] [-O originator] [-o outfile] [-p priority]\n\
        [-L class] [-r responsible] [-S submitter] [-s state] [-t text]\n\
-       [--full] [--help] [--sql] [--print-path] [--summary] [--version]\n\
-       [--skip-closed] [--category=category] [--confidential=yes|no]\n\
-       [--directory=directory] [--output=outfile] [--originator=name]\n\
-       [--priority=level] [--class=class] [--responsible=person]\n\
+       [-y synopsis] [-A release] [--full] [--help] [--print-path] [--version]\n\
+       [--summary] [--sql] [--skip-closed] [--category=category]\n\
+       [--confidential=yes|no] [--directory=directory] [--output=outfile]\n\
+       [--originator=name] [--priority=level] [--class=class]\n\
+       [--responsible=person] [--release=release] [--restricted]\n\
        [--quarter=quarter] [--keywords=regexp]\n\
        [--required-before=date] [--required-after=date]\n\
+       [--arrived-before=date] [--arrived-after=date]\n\
        [--severity=severity] [--state=state] [--submitter=submitter]\n\
        [--list-categories] [--list-responsible] [--list-submitters]\n\
-       [--text=text] [--multitext=mtext] [PR] [PR]...\n",
+       [--synopsis=synopsis] [--text=text] [--multitext=mtext] [PR] [PR]...\n",
 	   program_name);
 #else
   fprintf (stderr, "\
-Usage: %s [-FhiPqVx] [-C confidential] [-c category] [-d directory]\n\
+Usage: %s [-FhiPRqVx] [-C confidential] [-c category] [-d directory]\n\
        [-e severity] [-m mtext] [-O originator] [-o outfile] [-p priority]\n\
        [-L class] [-r responsible] [-S submitter] [-s state] [-t text]\n\
-       [--full] [--help] [--sql] [--print-path] [--summary] [--version]\n\
-       [--skip-closed] [--category=category] [--confidential=yes|no]\n\
-       [--directory=directory] [--output=outfile] [--originator=name]\n\
-       [--priority=level] [--class=class] [--responsible=person]\n\
-       [--quarter=quarter] [--keywords=regexp]\n\
+       [-y synopsis] [-A release] [--full] [--help] [--print-path] [--version]\n\
+       [--summary] [--sql] [--skip-closed] [--category=category]\n\
+       [--confidential=yes|no] [--directory=directory] [--output=outfile]\n\
+       [--originator=name] [--priority=level] [--class=class]\n\
+       [--responsible=person] [--release=release] [--restricted]\n\
+       [--arrived-before=date] [--arrived-after=date]\n\
        [--severity=severity] [--state=state] [--submitter=submitter]\n\
        [--list-categories] [--list-responsible] [--list-submitters]\n\
-       [--text=text] [--multitext=mtext] [PR] [PR]...\n",
+       [--synopsis=synopsis] [--text=text] [--multitext=mtext] [PR] [PR]...\n",
 	   program_name);
 #endif
   exit (s);
